@@ -1,41 +1,59 @@
-
+use 5.008003;
 use strict;
 use warnings;
 
 package IPC::Run::Fused::Win32;
-BEGIN {
-  $IPC::Run::Fused::Win32::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $IPC::Run::Fused::Win32::VERSION = '0.04000100';
-}
+
+our $VERSION = '1.000000';
+
+# ABSTRACT: Implementation of IPC::Run::Fused for Win32
+
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 use IO::Handle;
 use Module::Runtime;
 
-# ABSTRACT: Implementation of IPC::Run::Fused for Win32
 
 
-sub _fail { goto \&IPC::Run::Fused::_fail }
 
-BEGIN {
 
-  Module::Runtime::require_module('Socket');
 
-  Socket->import();
 
-}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+use IPC::Run::Fused qw(_fail);
+use Socket qw( AF_UNIX SOCK_STREAM PF_UNSPEC );
+
+use Exporter qw(import);
+our @EXPORT_OK = qw( run_fused );
 
 sub run_fused {
-  my ( $read_handle, @params ) = @_;
-  if ( ref $params[0] and ref $params[0] eq 'CODE' ) {
+  my ( undef, @params ) = @_;
+  if ( ref $params[0] and 'CODE' eq ref $params[0] ) {
     goto \&_run_fused_coderef;
   }
   goto \&_run_fused_job;
 }
 
-sub _run_fused_job {
-  my ( $read_handle, @params ) = @_;
+sub _run_fused_job {    ## no critic (Subroutines::RequireArgUnpacking)
+  my ( $read_handle, @params ) = ( \shift @_, @_ );
 
   my $config = _run_fused_jobdecode(@params);
 
@@ -53,9 +71,9 @@ sub _run_fused_job {
 
   Module::Runtime::require_module('Win32::Job');
 
-  pipe( $_[0], my $writer );
+  pipe ${$read_handle}, my $writer;
 
-  if ( my $pid = fork() ) {
+  if ( my $pid = fork ) {
     return $pid;
   }
 
@@ -66,12 +84,12 @@ sub _run_fused_job {
     {
       stdout => $writer,
       stderr => $writer,
-    }
+    },
   ) or _fail('Could not spawn job');
   my $result = $job->run( -1, 0 );
   if ( not $result ) {
     my $status = $job->status();
-    if ( exists $status->{exitcode} and $status->{exitcode} == 293 ) {
+    if ( exists $status->{exitcode} and 293 == $status->{exitcode} ) {
       _fail('Process used more than allotted time');
     }
     _fail( 'Child process terminated with exit code' . $status->{exitcode} );
@@ -82,9 +100,9 @@ sub _run_fused_job {
 sub _run_fused_jobdecode {
   my (@params) = @_;
 
-  if ( ref $params[0] and ref $params[0] eq 'SCALAR' ) {
+  if ( ref $params[0] and 'SCALAR' eq ref $params[0] ) {
     my $command = ${ $params[0] };
-    $command =~ s/^\s*//;
+    $command =~ s/\A\s*//msx;
     return {
       command    => $command,
       executable => _win32_command_find_invocant($command),
@@ -96,20 +114,21 @@ sub _run_fused_jobdecode {
   };
 }
 
-sub _run_fused_coderef {
-  my ( $read_handle, $code ) = @_;
+sub _run_fused_coderef {    ## no critic (Subroutines::RequireArgUnpacking)
+  my ( $read_handle, $code ) = ( \shift @_, @_ );
   my ( $reader, $writer );
 
-  socketpair( $reader, $writer, AF_UNIX, SOCK_STREAM, PF_UNSPEC ), and shutdown( $reader, 1 ), and shutdown( $writer, 0 ),
-    or _fail("creating socketpair");
+  socketpair $reader, $writer, AF_UNIX, SOCK_STREAM, PF_UNSPEC or _fail('creating socketpair');
+  shutdown $reader, 1 or _fail('Cant close write to reader');
+  shutdown $writer, 0 or _fail('Cant close read to writer');
 
-  if ( my $pid = fork() ) {
-    $_[0] = $reader;
+  if ( my $pid = fork ) {
+    ${$read_handle} = $reader;
     return $pid;
   }
 
-  close *STDERR;
-  close *STDOUT;
+  close *STDERR or _fail('Closing STDERR');
+  close *STDOUT or _fail('Closing STDOUT');
   open *STDOUT, '>>&=', $writer or _fail('Assigning to STDOUT');
   open *STDERR, '>>&=', $writer or _fail('Assigning to STDERR');
   $code->();
@@ -117,37 +136,42 @@ sub _run_fused_coderef {
 
 }
 
-our $BACKSLASH         = chr(92);
+our $BACKSLASH         = chr 92;
 our $DBLBACKSLASH      = $BACKSLASH x 2;
 our $DOS_SPECIAL_CHARS = {
-  chr(92) => [ 'backslash ',    $BACKSLASH x 2 ],
-  chr(34) => [ 'double-quotes', $BACKSLASH . chr(34) ],
+  chr 92 => [ 'backslash ',    $BACKSLASH x 2 ],
+  chr 34 => [ 'double-quotes', $BACKSLASH . chr 34 ],
 
   #chr(60) => ['open angle bracket', $backslash . chr(60)],
   #chr(62) => ['close angle bracket', $backslash . chr(62)],
 };
 our $DOS_REV_CHARS = {
   map { ( $DOS_SPECIAL_CHARS->{$_}->[1], [ $DOS_SPECIAL_CHARS->{$_}->[0], $_ ] ) }
-    keys %{$DOS_SPECIAL_CHARS}
+    keys %{$DOS_SPECIAL_CHARS},
 };
 
 sub _win32_escape_command_char {
-  return $_[0] unless exists $DOS_SPECIAL_CHARS->{ $_[0] };
-  return $DOS_SPECIAL_CHARS->{ $_[0] }->[1];
+  my ($char) = @_;
+  return $char unless exists $DOS_SPECIAL_CHARS->{$char};
+  return $DOS_SPECIAL_CHARS->{$char}->[1];
 }
 
 sub _win32_escape_command_token {
+  ## no critic (RegularExpressions)
   my $chars = join q{}, map { _win32_escape_command_char($_) } split //, shift;
   return qq{"$chars"};
 }
 
 sub _win32_escape_command {
-  return join q{ }, map { _win32_escape_command_token($_) } @_;
+  my (@tokens) = @_;
+  return join q{ }, map { _win32_escape_command_token($_) } @tokens;
 }
 
 sub _win32_command_find_invocant {
-  my ($command) = "$_[0]";
-  my $first = "";
+  my ($command) = @_;
+  $command = "$command";
+  my $first = q[];
+  ## no critic (RegularExpressions)
   my @chars = split //, $command;
   my $inquote;
 
@@ -155,12 +179,12 @@ sub _win32_command_find_invocant {
     my $char  = $chars[0];
     my $dchar = $chars[0] . $chars[1];
 
-    if ( not $inquote and $char eq q{"} ) {
+    if ( not $inquote and q["] eq $char ) {
       $inquote = 1;
       shift @chars;
       next;
     }
-    if ( $inquote and $char eq q{"} ) {
+    if ( $inquote and q["] eq $char ) {
       $inquote = undef;
       shift @chars;
       next;
@@ -171,14 +195,14 @@ sub _win32_command_find_invocant {
       shift @chars;
       next;
     }
-    if ( $char eq q{ } and not $inquote ) {
+    if ( q[ ] eq $char and not $inquote ) {
       if ( not length $first ) {
         shift @chars;
         next;
       }
       return $first;
     }
-    if ( $char eq q{ } and $inquote ) {
+    if ( q[ ] eq $char and $inquote ) {
       $first .= $char;
       shift @chars;
       next;
@@ -198,13 +222,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 IPC::Run::Fused::Win32 - Implementation of IPC::Run::Fused for Win32
 
 =head1 VERSION
 
-version 0.04000100
+version 1.000000
 
 =head1 METHODS
 
@@ -226,9 +252,10 @@ $fh will be clobbered like 'open' does, and $cmd, @args will be passed, as-is, t
 
 $fh will point to an IO::Handle attached to the end of a pipe running back to the called application.
 
-the command will be run in a fork, and stderr and stdout "fused" into a singluar pipe.
+the command will be run in a fork, and C<STDERR> and C<STDOUT> "fused" into a singular pipe.
 
-B<NOTE:> at present, STDIN's FD is left unchanged, and child processes will inherit parent STDIN's, and will thus block ( somewhere ) waiting for response.
+B<NOTE:> at present, C<STDIN>'s FD is left unchanged, and child processes will inherit parent C<STDIN>'s, and will thus block
+( somewhere ) waiting for response.
 
 =head1 AUTHOR
 
@@ -236,7 +263,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
